@@ -261,7 +261,7 @@ sw_multicast_socket_super_init(
 	err = sw_translate_error(self->m_desc != SW_INVALID_SOCKET, sw_socket_errno());
 	sw_check_okay_log(err, exit);
 
-#if defined(__APPLE__) || defined(__VXWORKS__)
+#if defined(__APPLE__) || defined(__VXWORKS__) || defined(__FreeBSD__)
    res = setsockopt(self->m_desc, SOL_SOCKET, SO_REUSEPORT, (char*) &opt, sizeof(opt));
 #else
 	res = setsockopt(self->m_desc, SOL_SOCKET, SO_REUSEADDR, (char*) &opt, sizeof(opt));
@@ -865,12 +865,19 @@ sw_socket_tcp_close(
 
 #if defined(WIN32)
 	res = shutdown(self->m_desc, SD_SEND);
-	res = 0;
 #else
 	res = shutdown(self->m_desc, 2);
+
+	/*
+	 * Patch from Michael (macallan18@earthlink.net)
+	 * 
+	 * we should only fail here if errno isn't ENOTCONN or ENOENT ( Solaris 9 sets errno to ENOENT 
+	 * if the socket isn't connected, despite the man page for shutdown saying it would use
+	 * ENOTCONN )
+	 */
+	err = sw_translate_error((res == 0) || (errno == ENOENT) || (errno == ENOTCONN), sw_socket_errno());
+   sw_check_okay_log(err, exit);
 #endif
-	err = sw_translate_error(res == 0, sw_socket_errno());
-	sw_check_okay_log(err, exit);
 
 	res = sw_close_socket(self->m_desc);
 	err = sw_translate_error(res == 0, sw_socket_errno());
